@@ -1,5 +1,5 @@
 """
-argparse middleware library.
+Middleware library for argparse.
 
 argparseware is designed as a turnkey library for developers who like the
 standard library, most specifically argparse. It extends the built-in argparse
@@ -8,17 +8,7 @@ simple syntax, improving reusability, while not compromising or reinventing
 the programming interfaces they already know.
 """
 
+from .core import middleware
+from .core import IMiddleware
+from .core import WrapperMiddleware
 from .core import ArgumentParser
-
-
-# Package version
-__version__ = '0.9.5'
-__versiont__ = (0, 9, 5)
-
-# Author information
-__author__ = 'Francis Lacroix'
-__author_email__ = 'f@relevance.io'
-
-# License information
-__license__ = 'TBD'
-__copyright__ = 'Relevance.io 2019-'
